@@ -155,14 +155,16 @@ package2remote <- function(name, lib = .libPaths(), repos = getOption("repos"),
       subdir = x$RemoteSubdir,
       username = x$RemoteUsername,
       ref = x$RemoteRef,
-      sha = x$RemoteSha),
+      sha = x$RemoteSha,
+      auth_token = github_pat()),
     gitlab = remote("gitlab",
       host = x$RemoteHost,
       repo = x$RemoteRepo,
       subdir = x$RemoteSubdir,
       username = x$RemoteUsername,
       ref = x$RemoteRef,
-      sha = x$RemoteSha),
+      sha = x$RemoteSha,
+      auth_token = gitlab_pat()),
     xgit = remote("xgit",
       url = trim_ws(x$RemoteUrl),
       ref = x$RemoteRef %||% x$RemoteBranch,
@@ -180,7 +182,9 @@ package2remote <- function(name, lib = .libPaths(), repos = getOption("repos"),
       username = x$RemoteUsername,
       ref = x$RemoteRef,
       sha = x$RemoteSha,
-      subdir = x$RemoteSubdir),
+      subdir = x$RemoteSubdir,
+      auth_user = bitbucket_user(),
+      password = bitbucket_password()),
     svn = remote("svn",
       url = trim_ws(x$RemoteUrl),
       svn_subdir = x$RemoteSubdir,
